
*	**********************************************************************	*
*	This file replicates Tables 1-5 of										*
*			THE EMPIRICAL APPENDIX OF										*
*	Hollyer, James R., B. Peter Rosendorff, James Raymond Vreeland			*
*	Transparency, Protest, and Autocratic Instability						*
*	American Political Science Review Vol. 109 No. 4						*
*	**********************************************************************	*

* Please change local DIR to your working directory:
*	**********************************************************************	*
local DIR = "C:\A\transpar\HRV_APSR_Replication_Materials\" 
cd "`DIR'" 
*	**********************************************************************	*

version 11

capture log close
clear
clear mata
clear matrix
set mem 500m
set more off
graph drop _all

log using "HRV_APSR_Tables_A1-A5.log", replace

use "HRV_APSR_Table1.dta", clear
	gen lag_transparency2=lag_transparency^2 

*Table A1. Cox Model Autocrat Removal via Revolt Only
		stset, clear 
		stset eyear, id(AutocRegimeID) origin(estartdate) failure(failrevoltonly) exit(failnotrevoltonly==1) scale(365.25) 
	*Cond. Past Collapse: 
		*Model 1:
		stcox lag_transparency lag_growth lag_trans_growth lag_GDP lag_open lag_party lag_mil, nohr strata(ever_collapse) cluster(AutocRegimeID) 
			estimates store revoltonly1 
		*Model 2:
		stcox lag_transparency lag_growth lag_trans_growth lag_party lag_mil, nohr strata(ever_collapse) cluster(AutocRegimeID) 
			estimates store revoltonly3 
		*Model 3:
		stcox lag_transparency lag_growth lag_trans_growth, nohr strata(ever_collapse) cluster(AutocRegimeID) 
			estimates store revoltonly2 
	*Cond. Hist. Instability: 
		*Model 4:
		stcox lag_transparency lag_growth lag_trans_growth lag_GDP lag_open lag_party lag_mil, nohr strata(hist_instability) cluster(AutocRegimeID) 
			estimates store revoltonly4 
		*Model 5:
		stcox lag_transparency lag_growth lag_trans_growth lag_party lag_mil, nohr strata(hist_instability) cluster(AutocRegimeID) 
			estimates store revoltonly5 
		*Model 6:
		stcox lag_transparency lag_growth lag_trans_growth, nohr strata(hist_instability) cluster(AutocRegimeID) 
			estimates store revoltonly6 
	*Control Past Collapse
		*Model 7:
		stcox lag_transparency lag_growth lag_trans_growth lag_GDP lag_open lag_party lag_mil ever_collapse, nohr cluster(AutocRegimeID) 
			estimates store revoltonly7 
		*Model 8:
		stcox lag_transparency lag_growth lag_trans_growth lag_party lag_mil ever_collapse, nohr cluster(AutocRegimeID) 
			estimates store revoltonly8 
		*Model 9:
		stcox lag_transparency lag_growth lag_trans_growth ever_collapse, nohr cluster(AutocRegimeID) 
			estimates store revoltonly9 
*Table A1 output in TeX:
	estout revoltonly1 revoltonly3 revoltonly2 revoltonly4 revoltonly5 revoltonly6 revoltonly7 revoltonly8 revoltonly9 using "HRV_APSR_TableA1.tex", cells(b(star fmt(3)) ci(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N_clust N_fail, labels("\# of Subjects" "\# of Failures")) style(tex) replace

	
*Table A2. Cox Model Autocrat Removal via Democratization Only
		stset, clear 
		stset eyear, id(AutocRegimeID) origin(estartdate) failure(faildemoconly) exit(failnotdemoconly==1) scale(365.25) 
	*Cond. Past Collapse: 
		*Model 1:
		stcox lag_transparency lag_growth lag_trans_growth lag_GDP lag_open lag_party lag_mil, nohr strata(ever_collapse) cluster(AutocRegimeID) 
			estimates store democonly1 
		*Model 2:
		stcox lag_transparency lag_growth lag_trans_growth lag_party lag_mil, nohr strata(ever_collapse) cluster(AutocRegimeID) 
			estimates store democonly2 
		*Model 3:
		stcox lag_transparency lag_growth lag_trans_growth, nohr strata(ever_collapse) cluster(AutocRegimeID) 
			estimates store democonly3 
	*Cond. Hist. Instability: 
		*Model 4:
		stcox lag_transparency lag_growth lag_trans_growth lag_GDP lag_open lag_party lag_mil, nohr strata(hist_instability) cluster(AutocRegimeID) 
			estimates store democonly4 
		*Model 5:
		stcox lag_transparency lag_growth lag_trans_growth lag_party lag_mil, nohr strata(hist_instability) cluster(AutocRegimeID) 
			estimates store democonly5 
		*Model 6:
		stcox lag_transparency lag_growth lag_trans_growth, nohr strata(hist_instability) cluster(AutocRegimeID) 
			estimates store democonly6 
	*Control Past Collapse
		*Model 7:
		stcox lag_transparency lag_growth lag_trans_growth lag_GDP lag_open lag_party lag_mil ever_collapse, nohr cluster(AutocRegimeID) 
			estimates store democonly7 
		*Model 8:
		stcox lag_transparency lag_growth lag_trans_growth lag_party lag_mil ever_collapse, nohr cluster(AutocRegimeID) 
			estimates store democonly8 
		*Model 9:
		stcox lag_transparency lag_growth lag_trans_growth ever_collapse, nohr cluster(AutocRegimeID) 
			estimates store democonly9 
*Table A2 output in TeX:
	estout democonly1 democonly2 democonly3 democonly4 democonly5 democonly6 democonly7 democonly8 democonly9 using "HRV_APSR_TableA2.tex", cells(b(star fmt(3)) ci(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N_clust N_fail, labels("\# of Subjects" "\# of Failures")) style(tex) replace


*Table A3. Cox Model Autocrat Removal via Coup
		stset, clear
		stset eyear, id(AutocRegimeID) origin(estartdate) failure(failcoup) exit(failnotcoup==1) scale(365.25)
	*Cond. Past Collapse: 
		*Model 1:
		stcox lag_transparency lag_growth lag_trans_growth lag_GDP lag_open lag_open2 lag_open3 lag_party lag_mil, nohr strata(ever_collapse) cluster(AutocRegimeID)
			estimates store coupstability1 
		*Model 2:
		stcox lag_transparency lag_growth lag_trans_growth lag_party lag_mil, nohr strata(ever_collapse) cluster(AutocRegimeID) 
			estimates store coupstability2 
		*Model 3:
		stcox lag_transparency lag_growth lag_trans_growth, nohr strata(ever_collapse) cluster(AutocRegimeID) 
			estimates store coupstability3 
	*Cond. Hist. Instability: 
		*Model 4:
		stcox lag_transparency lag_growth lag_trans_growth lag_GDP lag_open lag_open2 lag_open3 lag_party lag_mil, nohr strata(hist_instability) cluster(AutocRegimeID) 
			estimates store coupstability4 
		*Model 5:
		stcox lag_transparency lag_growth lag_trans_growth lag_party lag_mil, nohr strata(hist_instability) cluster(AutocRegimeID) 
			estimates store coupstability5 		
		*Model 6:
		stcox lag_transparency lag_growth lag_trans_growth, nohr strata(hist_instability) cluster(AutocRegimeID) 
			estimates store coupstability6 
	*Control Past Collapse
		*Model 7:
		stcox lag_transparency lag_growth lag_trans_growth lag_GDP lag_open lag_open2 lag_open3 lag_party lag_mil ever_collapse, nohr cluster(AutocRegimeID) 
			estimates store coupstability7 
		*Model 8:
		stcox lag_transparency lag_growth lag_trans_growth lag_party lag_mil ever_collapse, nohr cluster(AutocRegimeID) 
			estimates store coupstability8 
		*Model 9:
		stcox lag_transparency lag_growth lag_trans_growth ever_collapse, nohr cluster(AutocRegimeID) 
			estimates store coupstability9 
*Table A3 output in TeX:
	estout coupstability1 coupstability2 coupstability3 coupstability4 coupstability5 coupstability6 coupstability7 coupstability8 coupstability9 using "HRV_APSR_TableA3.tex", cells(b(star fmt(3)) ci(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N_clust N_fail, labels("\# of Subjects" "\# of Failures")) style(tex) replace


*Table A4. Cox Models Autocrat Removal via All Methods
		stset, clear 
		stset eyear, id(AutocRegimeID) origin(estartdate) failure(failyear) scale(365.25) 
	*Cond. Past Collapse: 
		*Model 1:
		stcox lag_transparency lag_growth lag_trans_growth lag_GDP lag_open lag_open2 lag_open3 lag_party lag_mil, nohr strata(ever_collapse) cluster(AutocRegimeID) 
			estimates store allstability1 
		*Model 2:
		stcox lag_transparency lag_growth lag_trans_growth lag_party lag_mil, nohr strata(ever_collapse) cluster(AutocRegimeID) 
			estimates store allstability2 
		*Model 3:
		stcox lag_transparency lag_growth lag_trans_growth, nohr strata(ever_collapse) cluster(AutocRegimeID) 
			estimates store allstability3 
	*Cond. Hist. Instability: 
		*Model 4:
		stcox lag_transparency lag_growth lag_trans_growth lag_GDP lag_open lag_open2 lag_open3 lag_party lag_mil, nohr strata(hist_instability) cluster(AutocRegimeID) 
			estimates store allstability4 
		*Model 5:
		stcox lag_transparency lag_growth lag_trans_growth lag_party lag_mil, nohr strata(hist_instability) cluster(AutocRegimeID) 
			estimates store allstability5 
		*Model 6:
		stcox lag_transparency lag_growth lag_trans_growth, nohr strata(hist_instability) cluster(AutocRegimeID) 
			estimates store allstability6 
	*Control Past Collapse
		*Model 7:
		stcox lag_transparency lag_growth lag_trans_growth lag_GDP lag_open lag_open2 lag_open3 lag_party lag_mil ever_collapse, nohr cluster(AutocRegimeID) 
			estimates store allstability7 
		*Model 8:
		stcox lag_transparency lag_growth lag_trans_growth lag_party lag_mil ever_collapse, nohr cluster(AutocRegimeID) 
			estimates store allstability8 
		*Model 9:
		stcox lag_transparency lag_growth lag_trans_growth ever_collapse, nohr cluster(AutocRegimeID) 
			estimates store allstability9 
*Table A4 output in TeX:
	estout allstability1 allstability2 allstability3 allstability4 allstability5 allstability6 allstability7 allstability8 allstability9 using "HRV_APSR_TableA4.tex", cells(b(star fmt(3)) ci(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N_clust N_fail, labels("\# of Subjects" "\# of Failures")) style(tex) replace 


*Table A5. Cox Model Including a quadratic Term of Transparency
		stset, clear 
		stset eyear, id(AutocRegimeID) origin(estartdate) failure(failrevolt) exit(failnotrevolt==1) scale(365.25)
	*Cond. Past Collapse: 
		*Model 1:
		stcox lag_transparency lag_transparency2 lag_growth lag_trans_growth lag_GDP lag_open lag_open2 lag_open3 lag_party lag_mil, nohr strata(ever_collapse) cluster(AutocRegimeID) 
			estimates store quadtrans1 
			estat phtest, rank detail 
		*Model 2:
		stcox lag_transparency lag_transparency2 lag_growth lag_trans_growth lag_party lag_mil, nohr strata(ever_collapse) cluster(AutocRegimeID) 
			estimates store quadtrans2 
			estat phtest, rank detail 
		*Model 3:
		stcox lag_transparency lag_transparency2 lag_growth lag_trans_growth, nohr strata(ever_collapse) cluster(AutocRegimeID) 
			estimates store quadtrans3 
			estat phtest, rank detail 
	*Cond. Hist. Instability: 
		*Model 4:
		stcox lag_transparency lag_transparency2 lag_growth lag_trans_growth lag_GDP lag_open lag_open2 lag_open3 lag_party lag_mil, nohr strata(hist_instability) cluster(AutocRegimeID) 
			estimates store quadtrans4 
			estat phtest, rank detail 
		*Model 5:
		stcox lag_transparency lag_transparency2 lag_growth lag_trans_growth lag_party lag_mil, nohr strata(hist_instability) cluster(AutocRegimeID) 
			estimates store quadtrans5 
			estat phtest, rank detail 
		*Model 6:
		stcox lag_transparency lag_transparency2 lag_growth lag_trans_growth, nohr strata(hist_instability) cluster(AutocRegimeID) 
			estimates store quadtrans6 
			estat phtest, rank detail 
	*Control Past Collapse
		*Model 7:
		stcox lag_transparency lag_transparency2 lag_growth lag_trans_growth lag_GDP lag_open lag_open2 lag_open3 lag_party lag_mil ever_collapse, nohr cluster(AutocRegimeID) 
			estimates store quadtrans7 
			estat phtest, rank detail 
		*Model 8:
		stcox lag_transparency lag_transparency2 lag_growth lag_trans_growth lag_party lag_mil ever_collapse, nohr cluster(AutocRegimeID) 
			estimates store quadtrans8 
			estat phtest, rank detail 
		*Model 9:
		stcox lag_transparency lag_transparency2 lag_growth lag_trans_growth ever_collapse, nohr cluster(AutocRegimeID) 
			estimates store quadtrans9 
			estat phtest, rank detail 
*Table A5 output in TeX:
	estout quadtrans1 quadtrans2 quadtrans3 quadtrans4 quadtrans5 quadtrans6 quadtrans7 quadtrans8 quadtrans9 using "HRV_APSR_TableA5.tex", cells(b(star fmt(3)) ci(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N_clust N_fail, labels("\# of Subjects" "\# of Failures")) style(tex) replace

	
log close
