
*	**********************************************************************	*
*	This file replicates Tables 6 & 7 of									*
*			THE EMPIRICAL APPENDIX OF										*
*	Hollyer, James R., B. Peter Rosendorff, James Raymond Vreeland			*
*	Transparency, Protest, and Autocratic Instability						*
*	American Political Science Review Vol. 109 No. 4						*
*	**********************************************************************	*

* Please change local DIR to your working directory:
*	**********************************************************************	*
local DIR = "C:\A\transpar\HRV_APSR_Replication_Materials\" 
cd "`DIR'" 
*	**********************************************************************	*

version 11

capture log close
clear
clear mata
clear matrix
set mem 500m
set more off
graph drop _all

log using "HRV_APSR_Tables_A6_&_A7.log", replace

use "HRV_APSR_Tables_A6_&_A7.dta", clear

*Data previously stset as: 
        *stset eyear, id(AutocRegimeID) origin(estartdate) failure(failrevolt) exit(failnotrevolt==1) scale(365.25)


*Table A6. Cox Model KOF Measure of Economic Openness
        *Cond. Past Collapse: 
                *Model 1:
                stcox lag_transparency lag_growth lag_trans_growth lag_GDP lag_kof lag_party lag_mil, nohr strata(ever_collapse) cluster (AutocRegimeID) 
                        estimates store KOF1 
                *Model 2:
                stcox lag_transparency lag_growth lag_trans_growth lag_kof, nohr strata(ever_collapse) cluster(AutocRegimeID) 
                        estimates store KOF2 
        *Cond. Hist. Instability: 
                *Model 3:
                stcox lag_transparency lag_growth lag_trans_growth lag_GDP lag_kof lag_party lag_mil, nohr strata(hist_instability) cluster(AutocRegimeID) 
                        estimates store KOF3 
                *Model 4:
                stcox lag_transparency lag_growth lag_trans_growth lag_kof, nohr strata(hist_instability) cluster(AutocRegimeID) 
                        estimates store KOF4 
        *Control Past Collapse
                *Model 5:
                stcox lag_transparency lag_growth lag_trans_growth lag_GDP lag_kof lag_party lag_mil ever_collapse, nohr cluster(AutocRegimeID) 
                        estimates store KOF5 
                *Model 6:
                stcox lag_transparency lag_growth lag_trans_growth lag_kof ever_collapse, nohr cluster(AutocRegimeID) 
                        estimates store KOF6 
*Table A6 output in TeX:
        estout KOF1 KOF2 KOF3 KOF4 KOF5 KOF6 using "HRV_APSR_TableA6.tex", cells(b(star fmt(3)) ci(par fmt(3)) p(par(( )) fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N_clust N_fail, labels("\# of Subjects" "\# of Failures")) style(tex) replace

        
*Table A7. Cox Model Wacziarg & Welch Measure of Economic Openness
        *Cond. Past Collapse: 
                *Model 1:
                stcox lag_transparency lag_growth lag_trans_growth lag_GDP lag_ww lag_party lag_mil, nohr strata(ever_collapse) cluster(AutocRegimeID) 
                        estimates store WW1 
                *Model 2:
                stcox lag_transparency lag_growth lag_trans_growth lag_ww, nohr strata(ever_collapse) cluster(AutocRegimeID) 
                        estimates store WW2 
        *Cond. Hist. Instability: 
                *Model 3:
                stcox lag_transparency lag_growth lag_trans_growth lag_GDP lag_ww lag_party lag_mil, nohr strata(hist_instability) cluster(AutocRegimeID) 
                        estimates store WW3 
                *Model 4:
                stcox lag_transparency lag_growth lag_trans_growth lag_ww, nohr strata(hist_instability) cluster(AutocRegimeID) 
                        estimates store WW4 
        *Control Past Collapse
                *Model 5:
                stcox lag_transparency lag_growth lag_trans_growth lag_GDP lag_ww lag_party lag_mil ever_collapse, nohr cluster(AutocRegimeID) 
                        estimates store WW5 
                *Model 6:
                stcox lag_transparency lag_growth lag_trans_growth lag_ww ever_collapse, nohr cluster(AutocRegimeID) 
                        estimates store WW6 
*Table A7 output in TeX:
        estout WW1 WW2 WW3 WW4 WW5 WW6 using "HRV_APSR_TableA7.tex", cells(b(star fmt(3)) ci(par fmt(3)) p(par(( )) fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N_clust N_fail, labels("\# of Subjects" "\# of Failures")) style(tex) replace 


log close
