
*	**********************************************************************	*
*	This file replicates Tables 8-13 of										*
*			THE EMPIRICAL APPENDIX OF										*
*	Hollyer, James R., B. Peter Rosendorff, James Raymond Vreeland			*
*	Transparency, Protest, and Autocratic Instability						*
*	American Political Science Review Vol. 109 No. 4						*
*	**********************************************************************	*

* Please change local DIR to your working directory:
*	**********************************************************************	*
local DIR = "C:\A\transpar\HRV_APSR_Replication_Materials\" 
cd "`DIR'" 
*	**********************************************************************	*

version 11

capture log close
clear
clear mata
clear matrix
set mem 500m
set more off
graph drop _all

log using "HRV_APSR_Tables_A8-A13.log", replace

use "HRV_APSR_Tables_A8-A13.dta", clear


*Table A8. Fixed-Effects Negative Binomial Models of Unrest, Including Freedom House Control
	*General Strikes
	xtnbreg GenStrikes L.GenStrikes L.transparencyindex L.grgdpch L.trans_growth L.rgdpch L.openk L.lparty_alt L.nmil oil L.NotFree t t2  if democracy==0, fe 
		estimates store FH1 
	*Riots
	xtnbreg Riots L.Riots L.transparencyindex L.grgdpch L.trans_growth L.rgdpch L.openk L.lparty_alt L.nmil oil L.NotFree t t2 if democracy==0, fe technique(dfp) 
		estimates store FH2 
	*Demonstrations
	xtnbreg AntiGovDem L.AntiGovDem L.transparencyindex L.grgdpch L.trans_growth L.rgdpch L.openk L.lparty_alt L.nmil oil L.NotFree t t2 if democracy==0, fe technique(dfp) 
		estimates store FH3 
	*Revolutions
	xtnbreg Revolutions L.Revolutions L.transparencyindex L.grgdpch L.trans_growth L.rgdpch L.openk L.lparty_alt L.nmil oil L.NotFree t t2 if democracy==0, fe technique(dfp) 
		estimates store FH4 
	*Guerilla
	xtnbreg Guerilla L.Guerilla L.transparencyindex L.grgdpch L.trans_growth L.rgdpch L.openk L.lparty_alt L.nmil oil L.NotFree t t2 if democracy==0, fe technique(dfp) 
		estimates store FH5 
	*Coups
	xtnbreg Coups L.Coups L.transparencyindex L.grgdpch L.trans_growth L.rgdpch L.openk L.lparty_alt L.nmil oil L.NotFree t t2 if democracy==0, fe technique(bfgs) 
		estimates store FH6 
	*Assassinations
	xtnbreg Assinations L.Assinations L.transparencyindex L.grgdpch L.trans_growth L.rgdpch L.openk L.lparty_alt L.nmil oil L.NotFree t t2 if democracy==0, fe technique(dfp) 
		estimates store FH7 
*Table A8 output in TeX:
	estout FH1 FH2 FH3 FH4 FH5 FH6 FH7 using "HRV_APSR_TableA8.tex", cells(b(star fmt(3)) ci(par fmt(3)) p(par(( )) fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N N_g, labels("\#Obs" "\#Countries")) style(tex) replace


*Table A9. Fixed-Effects Negative Binomial Models of Unrest, Including Freedom House Control
	*General Strikes
	xtnbreg GenStrikes L.GenStrikes L.transparencyindex L.grgdpch L.trans_growth L.NotFree if democracy==0, fe  
		estimates store FHsimp1 
	*Riots
	xtnbreg Riots L.Riots L.transparencyindex L.grgdpch L.trans_growth L.NotFree if democracy==0, fe technique(dfp) 
		estimates store FHsimp2 
	*Demonstrations
	xtnbreg AntiGovDem L.AntiGovDem L.transparencyindex L.grgdpch L.trans_growth L.NotFree if democracy==0, fe technique(dfp) 
		estimates store FHsimp3 
	*Revolutions
	xtnbreg Revolutions L.Revolutions L.transparencyindex L.grgdpch L.trans_growth L.NotFree if democracy==0, fe technique(dfp) 
		estimates store FHsimp4 
	*Guerilla
	xtnbreg Guerilla L.Guerilla L.transparencyindex L.grgdpch L.trans_growth L.NotFree if democracy==0, fe technique(dfp) 
		estimates store FHsimp5 
	*Coups
	xtnbreg Coups L.Coups L.transparencyindex L.grgdpch L.trans_growth L.NotFree if democracy==0, fe technique(bfgs) 
		estimates store FHsimp6 
	*Assassinations
	xtnbreg Assinations L.Assinations L.transparencyindex L.grgdpch L.trans_growth L.NotFree if democracy==0, fe technique(dfp) 
		estimates store FHsimp7 
*Table A9 output in TeX:
	estout FHsimp1 FHsimp2 FHsimp3 FHsimp4 FHsimp5 FHsimp6 FHsimp7 using "HRV_APSR_TableA9.tex", cells(b(star fmt(3)) ci(par fmt(3)) p(par(( )) fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N N_g, labels("\#Obs" "\#Countries")) style(tex) replace


*Table A10. Fixed-Effects Negative Binomial Models of Unrest, Including KOF Control
	*General Strikes
	xtnbreg GenStrikes L.GenStrikes L.transparencyindex L.grgdpch L.trans_growth L.rgdpch L.lparty_alt L.nmil oil L.kofrestrictions t t2 t3  if democracy==0, fe 
		estimates store KOF1 
	*Riots
	xtnbreg Riots L.Riots L.transparencyindex L.grgdpch L.trans_growth L.rgdpch  L.lparty_alt L.nmil oil L.kofrestrictions t t2 t3  if democracy==0, fe technique(dfp) 
		estimates store KOF2 
	*Demonstrations
	xtnbreg AntiGovDem L.AntiGovDem L.transparencyindex L.grgdpch L.trans_growth L.rgdpch  L.lparty_alt L.nmil oil L.kofrestrictions t t2 t3  if democracy==0, fe technique(dfp) 
		estimates store KOF3 
	*Revolutions
	xtnbreg Revolutions L.Revolutions L.transparencyindex L.grgdpch L.trans_growth L.rgdpch L.lparty_alt L.nmil oil L.kofrestrictions t t2 t3  if democracy==0, fe technique(dfp) 
		estimates store KOF4 
	*Guerilla
	xtnbreg Guerilla L.Guerilla L.transparencyindex L.grgdpch L.trans_growth L.rgdpch L.lparty_alt L.nmil oil L.kofrestrictions t t2 t3  if democracy==0, fe technique(dfp) 
		estimates store KOF5 
	*Coups
	xtnbreg Coups L.Coups L.transparencyindex L.grgdpch L.trans_growth L.rgdpch L.lparty_alt L.nmil oil L.kofrestrictions t t2 t3  if democracy==0, fe technique(bfgs) 
		estimates store KOF6 
	*Assassinations
	xtnbreg Assinations L.Assinations L.transparencyindex L.grgdpch L.trans_growth L.rgdpch L.lparty_alt L.nmil oil L.kofrestrictions t t2 t3  if democracy==0, fe technique(dfp) 
		estimates store KOF7 
*Table A10 output in TeX:
	estout KOF1 KOF2 KOF3 KOF4 KOF5 KOF6 KOF7 using "HRV_APSR_TableA10.tex", cells(b(star fmt(3)) ci(par fmt(3)) p(par(( )) fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N N_g, labels("\#Obs" "\#Countries")) style(tex) replace


*Table A11. Fixed-Effects Negative Binomial Models of Unrest, Including KOF Control
	*General Strikes
	xtnbreg GenStrikes L.GenStrikes L.transparencyindex L.grgdpch L.trans_growth L.kofrestrictions if democracy==0, fe 
		estimates store KOFShort1 
	*Riots
	xtnbreg Riots L.Riots L.transparencyindex L.grgdpch L.trans_growth L.kofrestrictions if democracy==0, fe technique(dfp) 
		estimates store KOFShort2 
	*Demonstrations
	xtnbreg AntiGovDem L.AntiGovDem L.transparencyindex L.grgdpch L.trans_growth L.kofrestrictions if democracy==0, fe technique(dfp) 
		estimates store KOFShort3 
	*Revolutions
	xtnbreg Revolutions L.Revolutions L.transparencyindex L.grgdpch L.trans_growth L.kofrestrictions if democracy==0, fe technique(dfp) 
		estimates store KOFShort4 
	*Guerilla
	xtnbreg Guerilla L.Guerilla L.transparencyindex L.grgdpch L.trans_growth L.kofrestrictions if democracy==0, fe technique(dfp) 
		estimates store KOFShort5 
	*Coups
	xtnbreg Coups L.Coups L.transparencyindex L.grgdpch L.trans_growth L.kofrestrictions if democracy==0, fe technique(bfgs) 
		estimates store KOFShort6 
	*Assassinations
	xtnbreg Assinations L.Assinations L.transparencyindex L.grgdpch L.trans_growth L.kofrestrictions if democracy==0, fe technique(dfp) 
		estimates store KOFShort7 
*Table A11 output in TeX:
	estout KOFShort1 KOFShort2 KOFShort3 KOFShort4 KOFShort5 KOFShort6 KOFShort7 using "HRV_APSR_TableA11.tex", cells(b(star fmt(3)) ci(par fmt(3)) p(par(( )) fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N N_g, labels("\#Obs" "\#Countries")) style(tex) replace


*Table A12. Fixed-Effects Negative Binomial Models of Unrest, Including Wacziarg & Welch Control
	*General Strikes
	xtnbreg GenStrikes L.GenStrikes L.transparencyindex L.grgdpch L.trans_growth L.rgdpch L.lparty_alt L.nmil oil L.WW t t2 t3  if democracy==0, fe 
		estimates store WW1 
	*Riots
	xtnbreg Riots L.Riots L.transparencyindex L.grgdpch L.trans_growth L.rgdpch  L.lparty_alt L.nmil oil L.WW t t2 t3  if democracy==0, fe technique(dfp) 
		estimates store WW2 
	*Demonstrations
	xtnbreg AntiGovDem L.AntiGovDem L.transparencyindex L.grgdpch L.trans_growth L.rgdpch  L.lparty_alt L.nmil oil L.WW t t2 t3  if democracy==0, fe technique(dfp) 
		estimates store WW3 
	*Revolutions
	xtnbreg Revolutions L.Revolutions L.transparencyindex L.grgdpch L.trans_growth L.rgdpch L.lparty_alt L.nmil oil L.WW t t2 t3  if democracy==0, fe technique(dfp) 
		estimates store WW4 
	*Guerilla
	xtnbreg Guerilla L.Guerilla L.transparencyindex L.grgdpch L.trans_growth L.rgdpch L.lparty_alt L.nmil oil L.WW t t2 t3  if democracy==0, fe technique(dfp) 
		estimates store WW5 
	*Coups
	xtnbreg Coups L.Coups L.transparencyindex L.grgdpch L.trans_growth L.rgdpch L.lparty_alt L.nmil oil L.WW t t2 t3  if democracy==0, fe technique(bfgs) 
		estimates store WW6 
	*Assassinations
	xtnbreg Assinations L.Assinations L.transparencyindex L.grgdpch L.trans_growth L.rgdpch L.lparty_alt L.nmil oil L.WW t t2 t3  if democracy==0, fe technique(dfp) 
		estimates store WW7 
*Table A12 output in TeX:
	estout WW1 WW2 WW3 WW4 WW5 WW6 WW7 using "HRV_APSR_TableA12.tex", cells(b(star fmt(3)) ci(par fmt(3)) p(par(( )) fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N N_g, labels("\#Obs" "\#Countries")) style(tex) replace
	

*Table A13. Fixed-Effects Negative Binomial Models of Unrest, Including Wacziarg & Welch Control
	*General Strikes
	xtnbreg GenStrikes L.GenStrikes L.transparencyindex L.grgdpch L.trans_growth L.WW if democracy==0, fe 
		estimates store WWShort1 
	*Riots
	xtnbreg Riots L.Riots L.transparencyindex L.grgdpch L.trans_growth L.WW if democracy==0, fe technique(dfp) 
		estimates store WWShort2 
	*Demonstrations
	xtnbreg AntiGovDem L.AntiGovDem L.transparencyindex L.grgdpch L.trans_growth L.WW if democracy==0, fe technique(dfp) 
		estimates store WWShort3 
	*Revolutions
	xtnbreg Revolutions L.Revolutions L.transparencyindex L.grgdpch L.trans_growth L.WW if democracy==0, fe technique(dfp) 
		estimates store WWShort4 
	*Guerilla
	xtnbreg Guerilla L.Guerilla L.transparencyindex L.grgdpch L.trans_growth L.WW if democracy==0, fe technique(dfp) 
		estimates store WWShort5 
	*Coups
	xtnbreg Coups L.Coups L.transparencyindex L.grgdpch L.trans_growth L.WW if democracy==0, fe technique(bfgs) 
		estimates store WWShort6 
	*Assassinations
	xtnbreg Assinations L.Assinations L.transparencyindex L.grgdpch L.trans_growth L.WW if democracy==0, fe technique(dfp) 
		estimates store WWShort7 
*Table A13 output in TeX:
	estout WWShort1 WWShort2 WWShort3 WWShort4 WWShort5 WWShort6 WWShort7 using "HRV_APSR_TableA13.tex", cells(b(star fmt(3)) ci(par fmt(3)) p(par(( )) fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N N_g, labels("\#Obs" "\#Countries")) style(tex) replace


log close
